@@ -11,8 +11,11 @@ clusterize <- function(
 	mai.top = 0.1,                         # heat.map()
 	side.height = 1,                       # heat.map()
 	side.col = NULL,                       # heat.map()
+	side.srt = 0,                          # heat.map()
+	side.cex = 1,                          # heat.map()
 	col.heatmap = heat(),                  # heat.map()
 	zlim = "0 centered",                   # heat.map()
+	zlim.trim = 0.02,                      # heat.map()
 	norm = c("rows", "columns", "none"),   # heat.map()
 	norm.clust = TRUE,
 	norm.robust = FALSE,                   # heat.map()
@@ -24,7 +27,9 @@ clusterize <- function(
 	order.genes = NULL,
 	order.samples = NULL,
 	fun.dist = dist.COR,
-	fun.hclust = hclust.ward
+	fun.hclust = hclust.ward,
+	clust.genes = NULL,
+	clust.samples = NULL
 	) {
 	# Arg check
 	norm <- match.arg(norm)
@@ -63,16 +68,33 @@ clusterize <- function(
 		}
 	}
 	
-	# Clustering
-	clustGenes <- as.dendrogram(fun.hclust(fun.dist(t(expr))))
-	clustSamples <- as.dendrogram(fun.hclust(fun.dist(expr)))
+	if(!isFALSE(clust.genes)) {
+		# Perform clustering
+		if(is.null(clust.genes)) clust.genes <- fun.hclust(fun.dist(t(expr)))
+		
+		# Coerce to dendrogram
+		clust.genes <- as.dendrogram(clust.genes)
+		
+		# Custom tree reordering
+		if(is.function(order.genes)) clust.genes <- order.genes(clust.genes, expr)
+		
+		# Synchronize tree and table orders ('side' will be ordered according to 'expr' row names in heat.map())
+		expr <- expr[, labels(clust.genes) ]
+	}
 	
-	# Custom tree reordering
-	if(is.function(order.genes))   clustGenes <- order.genes(clustGenes, expr)
-	if(is.function(order.samples)) clustSamples <- order.samples(clustSamples, expr)
-	
-	# Synchronize tree and table orders ('side' will be ordered according to 'expr' row names in heat.map())
-	expr <- expr[ labels(clustSamples) , labels(clustGenes) ]
+	if(!isFALSE(clust.samples)) {
+		# Perform clustering
+		if(is.null(clust.samples)) clust.samples <- fun.hclust(fun.dist(expr))
+		
+		# Coerce to dendrogram
+		clust.samples <- as.dendrogram(clust.samples)
+		
+		# Custom tree reordering
+		if(is.function(order.samples)) clust.samples <- order.samples(clust.samples, expr)
+		
+		# Synchronize tree and table orders ('side' will be ordered according to 'expr' row names in heat.map())
+		expr <- expr[ labels(clust.samples) ,]
+	}
 	
 	if(isTRUE(plot)) {
 		# Layout call
@@ -94,25 +116,34 @@ clusterize <- function(
 			side = side,
 			side.height = side.height,
 			side.col = side.col,
+			side.srt = side.srt,
+			side.cex = side.cex,
 			col.heatmap = col.heatmap,
 			zlim = zlim,
+			zlim.trim = zlim.trim,
 			norm = ifelse(isTRUE(norm.clust), "none", norm),
 			norm.robust = norm.robust
 		)
 		
 		# Sample tree (top right)
 		par(mai=c(0, out$mai.left, mai.top, mai.right))
-		plot(clustSamples, leaflab="none", xaxs="i", yaxs="i", yaxt="n")
+		if(isFALSE(clust.samples)) { plot(x=NA, y=NA, xlim=0:1, ylim=0:1, xaxt="n", yaxt="n", bty="n", xlab="", ylab="")
+		} else                     { plot(clust.samples, leaflab="none", xaxs="i", yaxs="i", yaxt="n")
+		}
 		
 		# Gene tree (bottom left)
 		par(mai=c(out$mai.bottom, 0.1, 0.1, 0))
-		plot(clustGenes, leaflab="none", xaxs="i", yaxs="i", yaxt="n", horiz=TRUE)
+		if(isFALSE(clust.genes)) { plot(x=NA, y=NA, xlim=0:1, ylim=0:1, xaxt="n", yaxt="n", bty="n", xlab="", ylab="")
+		} else                   { plot(clust.genes, leaflab="none", xaxs="i", yaxs="i", yaxt="n", horiz=TRUE)
+		}
 		
 		# Legend (top+middle left)
-		if(length(out$legend) > 0) {
+		if(length(unlist(out$legend)) > 0) {
 			par(mai=c(0.1, 0.1, mai.top, 0.1), xpd=NA)
 			plot(x=NA, y=NA, xlim=0:1, ylim=0:1, xaxt="n", yaxt="n", xaxs="i", yaxs="i", bty="n", xlab="", ylab="")
-			legend(x="topleft", legend=names(out$legend), fill=out$legend, bg="#EEEEEE")
+			val <- paste(rep(names(rev(out$legend)), sapply(rev(out$legend), length)), unlist(lapply(rev(out$legend), names)), sep=" : ")
+			col <- unlist(rev(out$legend))
+			legend(x="topleft", legend=val, fill=col, bg="#EEEEEE")
 		}
 	} else {
 		# No graphical parameter to return without plot
@@ -120,8 +151,8 @@ clusterize <- function(
 	}
 	
 	# Invisibly return parameters for heatScale()
-	out$genes <- clustGenes
-	out$samples <- clustSamples
+	out$genes <- clust.genes
+	out$samples <- clust.samples
 	invisible(out)
 }
 
